pub fn prophoto_rgb_builder() -> GammaLutBuilderExpand description
Create a lookup table builder for the transfer functions used in ProPhoto RGB.
pub fn prophoto_rgb_builder() -> GammaLutBuilderCreate a lookup table builder for the transfer functions used in ProPhoto RGB.